@@ -21,7 +21,12 @@ __all__ = ['dict_concat', 'dictable', 'is_dictable']
 def nan2none(v):
     return None if is_nan(v) or (is_str(v) and (len(v.strip()) == 0 or v[0] == '#' or v == 'n/a')) else v
 
-
+def relabel_lower(v):
+    if is_str(v):
+        return v.strip().replace(' ', '_').replace('"','').replace("'",'').replace(',','').lower()
+    else:
+        return v    
+    
 def dict_concat(*dicts):
     """
     A method of turning a list of dicts into one happy dict sharing its keys
@@ -705,9 +710,9 @@ class dictable(Dict):
                 keys = keys[i:]
             return '\n\n'.join(res)
 
-    def sort(self, *by):
+    def sort(self, *by, **byval):
         """
-        Sorts the table either using a key, list of keys or functions of members
+        Sorts the table either using a key, list of keys or functions of members. Also allows sort on specific orders of the keys
         
         
         :Example:
@@ -726,11 +731,32 @@ class dictable(Dict):
         
         >>> d = d.sort(lambda b: b*3 % 11) ## sorting again by c but using a function
         >>> assert list(d.c) == list(range(11))
+        
+        :Example: Sorting based on specific values
+        ---------
+        >>> rs = dictable(key = list('abcdeffg'), gender = list('mmffmmff'))
+        >>> rs = rs.sort(key = ['c', 'a', 'f', 'd'], gender = ['f', 'm'])
+        
+        key|gender
+        ----------
+        c  |f     
+        a  |m     
+        f  |f     <--- female f before male f
+        f  |m     <---
+        d  |f     
+        g  |f     <--- g,b,e entries with no first key provided in sort, so move to bottom of list
+        b  |m     
+        e  |m    
         """
-        by = as_list(by)
-        if len(self) == 0 or len(by) == 0:
+        if len(self) == 0:
+            return self.copy()
+        elif len(by):
+            keys = self[by]            
+        elif len(byval):
+            dicts = {k : dict(zip(vals, range(len(vals)))) for k, vals in byval.items()}
+            keys = [[d.get(row[k], len(d)) for k,d in dicts.items()] for row in self]            
+        else:
             return self.copy()
-        keys = self[as_tuple(by)]
         keys2id = list(zip(keys, range(len(self))))
         _, rows = zip(*sort(keys2id))
         return type(self)({key: [value[i] for i in rows] for key, value in self.items()})
@@ -784,7 +810,7 @@ class dictable(Dict):
             sheet_name = 0
         df = io.parse(sheet_name)
         res = cls(df)
-        res = res.relabel(lambda v: v.strip().replace(' ', '_'))
+        res = res.relabel(lambda v: v.strip().replace(' ', '_').replace('"','').replace("'",''))
         res = res.do(nan2none)
         if floats:
             res = res.do(try_back(as_float), floats)
@@ -795,6 +821,9 @@ class dictable(Dict):
         if no_none:
             for col in as_list(no_none):
                 res = res.exc(**{col : None})
+        for col in [col for col in res.keys() if col.startswith('Unnamed:')]:
+            if set(res[col]) == set([None]):
+                res = res-col
         return res
     
     def unlist(self):
