@@ -1,7 +1,8 @@
 import jsonpickle as jp
 import re
 from pyg_base._types import is_int, is_float, is_str, is_date, is_bool, is_pd, is_arr
-from pyg_base._dates import dt, iso
+from pyg_base._as_list import as_list 
+from pyg_base._dates import dt, iso, uk2dt, dt2str
 from pyg_base._decorators import try_back
 from pyg_base._logger import logger
 from pyg_base._loop import loop
@@ -10,7 +11,7 @@ import datetime
 from functools import partial
 from enum import Enum
 import numpy as np
-
+import json
 
 _obj = '_obj'
 _data = 'data'
@@ -41,8 +42,6 @@ def decode_str(value):
     else:
         return res
 
-
-
 @loop(list, tuple)
 def _decode(value, date = None):
     if is_str(value):
@@ -102,7 +101,7 @@ def decode(value, date = None):
 loads = partial(decode, date = True)
 
 @loop(list, tuple)
-def _encode(value, unchanged = None):
+def _encode(value, unchanged = None, unchanged_keys = None):
     if hasattr(value, '_encode') and not isinstance(value, type):
         res = value._encode
         if not isinstance(res, str):
@@ -123,10 +122,15 @@ def _encode(value, unchanged = None):
     elif unchanged and isinstance(value, unchanged):
          return value
     elif isinstance(value, dict):
-        res = {k : _encode(v, unchanged) for k, v in value.items()}
+        unchanged_keys = as_list(unchanged_keys)
+        res = {k : v if unchanged_keys and k in unchanged_keys else _encode(v, unchanged, unchanged_keys) for k, v in value.items()}
         if _obj not in res and type(value)!=dict:
-            res[_obj] = _encode(type(value), unchanged)
+            res[_obj] = _encode(type(value), unchanged, unchanged_keys)
         return res
+    elif 'tensorflow.python.keras' in str(type(value)): ## A bit of a cheat not to have tensorflow explicit dependency
+        res = _encode(model_to_config_and_weights(value), unchanged, unchanged_keys)
+        res['_obj'] = _keras_from_config_and_weights
+        return res        
     elif is_pd(value):
         return {_data : pd2bson(value), _obj : _bson2pd}
     elif is_arr(value):
@@ -166,9 +170,9 @@ def _as_primitive(value):
 
 def as_primitive(value):
     return _as_primitive(value)
+    
 
-
-def encode(value, unchanged = None):
+def encode(value, unchanged = None, unchanged_keys = None):
     """
     
     encode/decode are performed prior to sending to mongodb or after retrieval from db. 
@@ -207,7 +211,53 @@ def encode(value, unchanged = None):
     A pre-json object
 
     """
-    return _encode(value, unchanged)
+    return _encode(value, unchanged, unchanged_keys)
+
+_uk2dt = encode(uk2dt)
+_array = encode(np.array)
+
+@loop(list, tuple, dict)
+def _dumps(value):
+    if is_date(value):
+        return dict(_obj = _uk2dt, t = dt2str(value))
+    elif isinstance(value, np.ndarray):
+        if len(value.shape) == 0:
+            return as_primitive(value)
+        elif len(value.shape) == 1:
+            return dict(_obj = _array, object = _dumps(list(value)))
+        elif len(value.shape) == 2:
+            return dict(_obj = _array, object = _dumps(list(map(list,value))))
+        elif len(value.shape) == 3:
+            return dict(_obj = _array, object = _dumps([list(map(list,v)) for v in value]))
+        else:
+            return as_primitive(value)
+    else:
+        return as_primitive(value)
+
+def dumps(value):
+    """
+    an extended version of json.dumps, being able to handle dates and arrays
+    """
+    value = _dumps(value)
+    return json.dumps(value)
+
+@loop(list, tuple, dict)
+def _loads(value):
+    """
+    an extended version of json.dumps, being able to handle dates and arrays
+    """
+    if isinstance(value, str):    
+        value = json.loads(value)
+        return decode(value)
+    else:
+        return value
+    
+def loads(value):
+    return _loads(value)    
+
+
+def model_to_config_and_weights(value):
+    return dict(model = type(value), weights = value.get_weights(), config = value.get_config())
 
 def pd2bson(value):
     """
@@ -254,7 +304,29 @@ def bson2pd(data):
         res.shape
         return res
     except Exception:
-        return None        
+        return None
     
+def keras_from_config_and_weights(model, config, weights):
+    """
+
+    Parameters
+    ----------
+    model : keras model
+        Keras model
+    config : str
+        json of the model.
+    weights : list of numpy arrays 
+        model weights
+
+    Returns
+    -------
+    res : keras model
+
+    """
+    res = model.from_config(config)
+    res.set_weights(weights)
+    return res
+    
+_keras_from_config_and_weights = encode(keras_from_config_and_weights)
 _bson2pd = encode(bson2pd)
 _bson2np = encode(bson2np)
